NodeConfig

Struct NodeConfig 

#[non_exhaustive]
pub struct NodeConfig { pub address: SocketAddr, pub authorization: String, pub user_id: Id<UserMarker>, pub enable_tls: bool, pub session_id: Option<String>, }
The configuration that a Node uses to connect to a Lavalink server.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
address: SocketAddr

The address of the node.

authorization: String

The password to use when authenticating.

user_id: Id<UserMarker>

The user ID of the bot.

enable_tls: bool

Whether or not to enable TLS.

session_id: Option<String>

Optional session ID to resume an existing Lavalink session.

If provided, the client will attempt to resume this session instead of creating a new one. This is only applicable for Lavalink v4+.

Implementations

Source

impl NodeConfig

pub fn new( user_id: Id<UserMarker>, address: impl Into<SocketAddr>, authorization: impl Into<String>, enable_tls: bool, ) -> Self

Create a new configuration for connecting to a node via Node::connect.

If adding a node through the Lavalink client then you don’t need to do this yourself.