pub struct NodeError { /* private fields */ }Expand description
An error occurred while either initializing a connection or while running its event loop.
Implementations
Sourceimpl NodeError
impl NodeError
Sourcepub const fn kind(&self) -> &NodeErrorType
pub const fn kind(&self) -> &NodeErrorType
Immutable reference to the type of error that occurred.
Sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
Sourcepub fn into_parts(self) -> (NodeErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(self) -> (NodeErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.